@@ -1,5 +1,6 @@
 # Logging
 from roguewave.log import logger
+from roguewave.tools.time import to_datetime_utc, to_datetime64
 
 # model time
 from roguewave.modeldata import (
@@ -17,6 +18,7 @@ from roguewave.modeldata import (
     generate_uris,
 )
 
+
 # Interpolate
 from roguewave.interpolate import (
     interpolate_dataset,
@@ -64,3 +66,5 @@ from roguewave.colocate import (
     colocated_tracks_as_dataset,
     colocate_model_spotter_spectra,
 )
+
+from roguewave.spotterapi import get_spotter_data
