@@ -1,6 +1,7 @@
 import numpy
 
-def wrapped_difference(delta, period=2*numpy.pi, discont=None):
+
+def wrapped_difference(delta, period=2 * numpy.pi, discont=None):
     """
     Calculate the wrapped difference for a given delta for a periodic variable.
     E.g. if the difference between two angles measured in degrees is 359 we
@@ -21,6 +22,9 @@ def wrapped_difference(delta, period=2*numpy.pi, discont=None):
         return delta
 
     if discont is None:
-        discont = period/2
+        discont = period / 2
 
-    return (delta + period - discont) % period - period + discont
\ No newline at end of file
+    with numpy.errstate(invalid="ignore"):
+        out = (delta + period - discont) % period - period + discont
+
+    return out
